@@ -15,6 +15,8 @@ class Doc(doc.Doc):
     生成数据库文档
     """
 
+    COLUMNS_SQL = 'SHOW FULL COLUMNS FROM `{table_name}`'
+
     def get_db_fields_info(self, table_name, cur_fields):
         """
         获取数据库中的字段信息
@@ -23,19 +25,23 @@ class Doc(doc.Doc):
         :return:
         """
 
-        sql = 'SHOW FULL COLUMNS FROM `' + table_name + '`'
+        sql = self.COLUMNS_SQL.format(table_name=table_name)
         self.cursor.execute(sql)
         for filed_info in self.cursor.fetchall():
+            filed_name = filed_info[0]
+            db_default_value = filed_info[5]
+            default_value = cur_fields[filed_name]['default']
+
             cur_filed_info = {
-                'field': filed_info[0],
+                'field': filed_name,
                 'type': filed_info[1],
                 'collation': filed_info[2],
                 'null': filed_info[3],
                 'key': filed_info[4],
-                'default': filed_info[5],
+                'default': db_default_value if db_default_value else default_value,
                 'extra': filed_info[6],
                 'privileges': filed_info[7],
                 'comment': filed_info[8]
             }
-            cur_fields[cur_filed_info['field']].update(cur_filed_info)
+            cur_fields[filed_name].update(cur_filed_info)
         return cur_fields
