@@ -34,7 +34,7 @@ class ModelCreatedBy(models.Model):
     created_by = models.ForeignKey(
         settings.AUTH_USER_MODEL,
         verbose_name=_('创建用户ID'),
-        related_name="%(app_label)s_%(class)s_created_by",
+        related_name="created_by_set",
         on_delete=helper.get_kelove_databases_settings('FOREIGN_DELETE_TYPE', models.PROTECT),
         db_constraint=helper.get_kelove_databases_settings('DB_CONSTRAINT_USER', False),
         null=True,
@@ -56,7 +56,7 @@ class ModelUpdatedBy(models.Model):
     updated_by = models.ForeignKey(
         settings.AUTH_USER_MODEL,
         verbose_name=_('更新用户ID'),
-        related_name="%(app_label)s_%(class)s_updated_by",
+        related_name="updated_by_set",
         on_delete=helper.get_kelove_databases_settings('FOREIGN_DELETE_TYPE', models.PROTECT),
         db_constraint=helper.get_kelove_databases_settings('DB_CONSTRAINT_USER', False),
         null=True,
@@ -164,7 +164,16 @@ class ModelBaseOnlyTime(ModelCreatedTime, ModelUpdatedTime):
         abstract = True
 
 
-class ModelBaseAll(ModelCreatedBy, ModelUpdatedBy, ModelBaseNoUser):
+class ModelBaseOnlyUser(ModelCreatedBy, ModelUpdatedBy):
+    """
+    数据模型基类（仅包含创建、更新用户字段）
+    """
+
+    class Meta:
+        abstract = True
+
+
+class ModelBaseAll(ModelBaseOnlyUser, ModelBaseOnlyTime, ModelStatus, ModelEnabled, ModelStatus):
     """
     数据模型基类(添加全部公用字段)
     """
